summaryrefslogtreecommitdiff
path: root/src/XUndefDevCur.c
diff options
context:
space:
mode:
authorPeter Hutterer <peter.hutterer@who-t.net>2009-02-25 15:53:29 +1000
committerPeter Hutterer <peter.hutterer@who-t.net>2009-03-11 14:26:04 +1000
commit6be974ec5597ef37fbd3a6057d52a38356f544e0 (patch)
tree5db0f6322dde1b6f9bc7e4f806b8f89c1a8ec33d /src/XUndefDevCur.c
parent60b2d114d06617ca60c2905373829299dc051c7f (diff)
Fix the already existing XI2 calls to the new XI2 protocol. FIXME
FIXME: not bisectable due to XiSelectInput. This includes namespacing them with an XI2 prefix. Affected calls: XIGetClientPointer XISetClientPointer XIDefineDeviceCursor XIUndefineDeviceCursor XIWarpDevicePointer XIQueryDevicePointer XIChangeDeviceHierarchy (+ event)
Diffstat (limited to 'src/XUndefDevCur.c')
-rw-r--r--src/XUndefDevCur.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/XUndefDevCur.c b/src/XUndefDevCur.c
index af20fff..81e312e 100644
--- a/src/XUndefDevCur.c
+++ b/src/XUndefDevCur.c
@@ -26,19 +26,19 @@ in this Software without prior written authorization from The Open Group.
/***********************************************************************
*
* XDefineDeviceCursor - Change the cursor of an extension input device.
*
*/
#include <X11/extensions/XI.h>
-#include <X11/extensions/XIproto.h>
#include <X11/Xlibint.h>
-#include <X11/extensions/XInput.h>
+#include <X11/extensions/XInput2.h>
#include <X11/extensions/extutil.h>
#include "XIint.h"
-int XUndefDeviceCursor(Display *dpy, XDevice* dev, Window w)
+int XIUndefineDeviceCursor(Display *dpy, XDevice* dev, Window w)
{
- return XDefineDeviceCursor(dpy, dev, w, None);
+ return XIDefineDeviceCursor(dpy, dev, w, None);
}
@@ -26,19 +26,19 @@ in this Software without prior written authorization from The Open Group.
/***********************************************************************
*
- * XDefineDeviceCursor - Change the cursor of an extension input device.
+ * XIUndefineDeviceCursor - Change the cursor of an extension input device to
+ * None..
*
*/